ClosureOnce3

Struct ClosureOnce3 

pub struct ClosureOnce3<A, B, C, R> { /* private fields */ }
A one-shot, typed closure with the given argument and result types.

Implementations

Source

impl<A: CType, B: CType, C: CType, R: CType> ClosureOnce3<A, B, C, R>

pub fn new<Callback>(callback: Callback) -> Self
where Callback: FnOnce(A, B, C) -> R + Any,

Constructs a typed closure callable from C from a Rust closure.

Source

impl<A: Copy, B: Copy, C: Copy, R: CType> ClosureOnce3<A, B, C, R>

pub fn new_with_cif<Callback>(cif: Cif3<A, B, C, R>, callback: Callback) -> Self
where Callback: FnOnce(A, B, C) -> R + Any,

Constructs a one-shot closure callable from C from a CIF describing the calling convention for the resulting function and the Rust closure to call.

Source

impl<A, B, C, R: CType> ClosureOnce3<A, B, C, R>

pub fn code_ptr(&self) -> &FnPtr3<'_, A, B, C, R>

Gets the C code pointer that is used to invoke the closure.

pub fn from_parts<U: Any>( cif: Cif3<A, B, C, R>, callback: CallbackOnce3<U, A, B, C, R::RetType>, userdata: U, ) -> Self

Constructs a one-shot closure callable from C from a CIF describing the calling convention for the resulting function, a callback for the function to call, and userdata to pass to the callback. Note that the return type of the callback must follow the libffi implicit extension rules.